@@ -5,23 +5,28 @@
 #           is to hold info for data export to Inside Mac Database
 #
 # Author: Matt Morse (matt@apple.com)
-# Last Updated: $Date: 2001/11/30 22:43:17 $
+# Last Updated: $Date: 2004/06/13 04:59:12 $
 #
-# Copyright (c) 1999-2001 Apple Computer, Inc.  All Rights Reserved.
-# The contents of this file constitute Original Code as defined in and are
-# subject to the Apple Public Source License Version 1.1 (the "License").
-# You may not use this file except in compliance with the License.  Please
-# obtain a copy of the License at http://www.apple.com/publicsource and
-# read it before using this file.
+# Copyright (c) 1999-2004 Apple Computer, Inc.  All rights reserved.
 #
-# This Original Code and all software distributed under the License are
-# distributed on an TAS ISU basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+# @APPLE_LICENSE_HEADER_START@
+#
+# This file contains Original Code and/or Modifications of Original Code
+# as defined in and that are subject to the Apple Public Source License
+# Version 2.0 (the 'License'). You may not use this file except in
+# compliance with the License. Please obtain a copy of the License at
+# http://www.opensource.apple.com/apsl/ and read it before using this
+# file.
+# 
+# The Original Code and all software distributed under the License are
+# distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 # EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
-# INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY, FITNESS
-# FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the License for
-# the specific language governing rights and limitations under the
-# License.
+# INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+# Please see the License for the specific language governing rights and
+# limitations under the License.
 #
+# @APPLE_LICENSE_HEADER_END@
 #
 ######################################################################
 
@@ -48,11 +53,35 @@ sub new {
 sub _initialize {
     my($self) = shift;
     $self->SUPER::_initialize();
-    $self->{POSITION} = undef;
-    $self->{TYPE} = undef;
+    # $self->{POSITION} = undef;
+    # $self->{TYPE} = undef;
     $self->{USERDICTARRAY} = ();
+    # $self->{HIDDEN} = 0;
+    $self->{CLASS} = "HeaderDoc::MinorAPIElement";
 }
 
+sub clone {
+    my $self = shift;
+    my $clone = undef;
+    if (@_) {
+	$clone = shift;
+    } else {
+	$clone = HeaderDoc::MinorAPIElement->new();
+    }
+
+    $self->SUPER::clone($clone);
+
+    # now clone stuff specific to function
+
+    $clone->{POSITION} = $self->{POSITION};
+    $clone->{TYPE} = $self->{TYPE};
+    $clone->{HIDDEN} = $self->{HIDDEN};
+    $clone->{USERDICTARRAY} = $self->{USERDICTARRAY};
+
+    return $clone;
+}
+
+
 sub position {
     my $self = shift;
 
@@ -62,6 +91,15 @@ sub position {
     return $self->{POSITION};
 }
 
+sub hidden {
+    my $self = shift;
+
+    if (@_) {
+        $self->{HIDDEN} = shift;
+    }
+    return $self->{HIDDEN};
+}
+
 sub type {
     my $self = shift;
 
@@ -109,6 +147,7 @@ sub printObject {
     my $self = shift;
     my $dec = $self->declaration();
  
+    $self->SUPER::printObject();
     print "position: $self->{POSITION}\n";
     print "type: $self->{TYPE}\n";
 }
