@@ -6,22 +6,28 @@
 # Initial modifications: SKoT McDonald <skot@tomandandy.com> Aug 2001
 #
 # Based on CPPClass by Matt Morse (matt@apple.com)
-# Last Updated: $Date: 2003/07/23 23:00:55 $
+# Last Updated: $Date: 2004/06/10 22:12:16 $
 # 
-# Copyright (c) 1999-2001 Apple Computer, Inc.  All Rights Reserved.
-# The contents of this file constitute Original Code as defined in and are
-# subject to the Apple Public Source License Version 1.1 (the "License").
-# You may not use this file except in compliance with the License.  Please
-# obtain a copy of the License at http://www.apple.com/publicsource and
-# read it before using this file.
+# Copyright (c) 1999-2004 Apple Computer, Inc.  All rights reserved.
 #
-# This Original Code and all software distributed under the License are
-# distributed on an TAS ISU basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+# @APPLE_LICENSE_HEADER_START@
+#
+# This file contains Original Code and/or Modifications of Original Code
+# as defined in and that are subject to the Apple Public Source License
+# Version 2.0 (the 'License'). You may not use this file except in
+# compliance with the License. Please obtain a copy of the License at
+# http://www.opensource.apple.com/apsl/ and read it before using this
+# file.
+# 
+# The Original Code and all software distributed under the License are
+# distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 # EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
-# INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY, FITNESS
-# FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the License for
-# the specific language governing rights and limitations under the
-# License.
+# INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+# Please see the License for the specific language governing rights and
+# limitations under the License.
+#
+# @APPLE_LICENSE_HEADER_END@
 #
 ######################################################################
 BEGIN {
@@ -44,7 +50,7 @@ $VERSION = '1.20';
 ################ Portability ###################################
 my $isMacOS;
 my $pathSeparator;
-if ($^O =~ /MacOS/i) {
+if ($^O =~ /MacOS/io) {
 	$pathSeparator = ":";
 	$isMacOS = 1;
 } else {
@@ -56,18 +62,19 @@ my $debugging = 0;
 my $tracing = 0;
 my $outputExtension = ".html";
 my $tocFrameName = "toc.html";
-my $theTime = time();
-my ($sec, $min, $hour, $dom, $moy, $year, @rest);
-($sec, $min, $hour, $dom, $moy, $year, @rest) = localtime($theTime);
-$moy++;
-$year += 1900;
-my $dateStamp = "$moy/$dom/$year";
+# my $theTime = time();
+# my ($sec, $min, $hour, $dom, $moy, $year, @rest);
+# ($sec, $min, $hour, $dom, $moy, $year, @rest) = localtime($theTime);
+# $moy++;
+# $year += 1900;
+# my $dateStamp = "$moy/$dom/$year";
 ######################################################################
 
 sub _initialize {
     my($self) = shift;
     $self->SUPER::_initialize();
     $self->tocTitlePrefix('Class:');
+    $self->{CLASS} = "HeaderDoc::ObjCClass";
 }
 
 sub getMethodType {
@@ -75,14 +82,16 @@ sub getMethodType {
 	my $declaration = shift;
 	my $methodType = "";
 		
-	if ($declaration =~ /^\s*-/) {
+	if ($declaration =~ /^\s*-/o) {
 	    $methodType = "instm";
-	} elsif ($declaration =~ /^\s*\+/) {
+	} elsif ($declaration =~ /^\s*\+/o) {
 	    $methodType = "clm";
 	} else {
-		my $filename = $HeaderDoc::headerObject->filename();
-		print "$filename:0:Unable to determine whether declaration is for an instance or class method.\n";
-		print "$filename:0:     '$declaration'\n";
+		# my $filename = $HeaderDoc::headerObject->filename();
+		my $filename = $self->filename();
+		my $linenum = $self->linenum();
+		print "$filename:$linenum:Unable to determine whether declaration is for an instance or class method[class].\n";
+		print "$filename:$linenum:     '$declaration'\n";
 	}
 	return $methodType;
 }
@@ -93,21 +102,19 @@ sub getMethodType {
 sub docNavigatorComment {
     my $self = shift;
     my $name = $self->name();
-    my $navComment = "<!-- headerDoc=cl; name=$name-->";
-    my $appleRef = "<a name=\"//apple_ref/occ/cl/$name\"></a>";
+    $name =~ s/;//sgo;
+    my $uid = $self->apiuid("cl"); # "//apple_ref/occ/cl/$name";
+    my $navComment = "<!-- headerDoc=cl; uid=$uid; name=$name-->";
+    my $appleRef = "<a name=\"$uid\"></a>";
     
     return "$navComment\n$appleRef";
 }
 
 ################## Misc Functions ###################################
 sub objName { # used for sorting
-   my $obj1 = $a;
-   my $obj2 = $b;
-   if ($HeaderDoc::sort_entries) {
-        return ($obj1->name() cmp $obj2->name());
-   } else {
-        return (1 cmp 2);
-   }
+    my $obj1 = $a;
+    my $obj2 = $b;
+    return ($obj1->name() cmp $obj2->name());
 }
 
 
